@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,24 +323,22 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.50 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-03-18.
 
 =head1 DESCRIPTION
 
 
-{en_US 
 The example(s) in this package are for demonstrating how the function metadata
 is converted into CLI help example (produced by C<--help> or C<--help --verbose>).
 Also for testing how it is converted into POD for scripts (i.e. the C<OPTIONS>
 section).
-}
 
 =head1 FUNCTIONS
 
 
 =head2 demo_cli_opts(%args) -> [status, msg, result, meta]
 
-{en_US Summary for `demo_cli_opts`}.
+Summary for `demo_cli_opts`.
 
 Examples:
 
@@ -356,7 +354,6 @@ Summary for an example.
 A second example.
 
 
-{en_US 
 Description for C<demo_cli_opts>.
 
 This is another paragraph from the description. Description by default is
@@ -364,44 +361,37 @@ assumed to be marked up in I<Markdown> (currently referring to CommonMark).
 
  This paragraph should be set in verbatim.
 
-}
-
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<are_baz> => I<bool>
 
-{en_US This demonstrate negation of --are-foo to --arent-foo}.
+This demonstrate negation of --are-foo to --arent-foo.
 
 =item * B<array1>* => I<array[str]>
 
-{en_US Positional, greedy, and plural}.
+Positional, greedy, and plural.
 
-{en_US 
 Argument with non-scalar types (like array or hash) can be specified in the CLI
 using C<--ARG-json> or C<--ARG-yaml>. Arguments with type of array of string can
 also be specified using multiple C<--ARG> options.
 
 This option also links to another option.
-}
 
 =item * B<bool1> => I<bool>
 
-{en_US A bool option}.
+A bool option.
 
-{en_US 
 CLI framework should generate C<--nobool1> (and C<--nobool1>) automatically.
 
 This option has an alias, C<-z>. Because the alias has its own
 summary/description, it will be displayed separately.
-}
 
 =item * B<flag1> => I<bool>
 
-{en_US A flag option}.
+A flag option.
 
-{en_US 
 A flag option is a bool option with the value of 1 (true). It is meant to
 activate something if specified and there is no notion of disabling by
 specifying the opposite. Thus the CLI framework should not generate a
@@ -410,76 +400,62 @@ C<--noflag1> option.
 This flag has an alias C<-f> with no summary/description nor code. So the CLI
 framework should display the alias along with the option. Note that short
 (single-letter) options/aliases do not get C<--noX>.
-}
 
 =item * B<full> => I<bool> (default: 1)
 
-{en_US Turn on full processing}.
+Turn on full processing.
 
-{en_US 
 Another bool option with on default.
 
 CLI framework should perhaps show C<--nobool2> instead of C<--bool2> because
 C<--bool2> is active by default. And if it does so, it should also show the
 negative summary in the C<summary.alt.bool.not> attribute instead of the normal
 C<summary> property.
-}
 
 =item * B<full2> => I<bool> (default: 1)
 
-{en_US Use full processing (2)}.
+Use full processing (2).
 
-{en_US 
 Another bool option with on default. Because this option does not have
 C<summary.alt.bool.not>, CLI framework should not show any summary, despite the
 existence of C<summary>.
-}
 
 =item * B<gender> => I<str>
 
-{en_US A string option}.
+A string option.
 
-{en_US 
 This option contains flag aliases that have code.
-}
 
 =item * B<hash1> => I<hash> (default: {default=>1})
 
-{en_US Demonstrate hash argument with default value from schema}.
+Demonstrate hash argument with default value from schema.
 
 =item * B<input> => I<buf>
 
-{en_US Specify input}.
+Specify input.
 
-{en_US 
 This option demonstrates the C<cmdline_src> property. Also, since schema type is
 C<buf>, we know that the value is binary data. CLI framework will provide
 C<--input-base64> to allow specifying binary data encoded in base64.
-}
 
 =item * B<int1>* => I<int>
 
-{en_US 
 Demonstrate an option with no summary. And a required option.
-}
 
 =item * B<int2> => I<int> (default: 10)
 
-{en_US Another int option}.
+Another int option.
 
-{en_US 
 Demonstrate a scalar/simple default value.
-}
 
 =item * B<is_bar> => I<bool>
 
-{en_US This demonstrate negation of --is-foo to --isnt-foo}.
+This demonstrate negation of --is-foo to --isnt-foo.
 
 =item * B<output> => I<str>
 
-{en_US Specify output filename}.
+Specify output filename.
 
-{en_US 
 This option demonstrates how the option would be displayed in the help/usage.
 Due to the C<x.schema.entity> attribute giving hint about what the value is, CLI
 framework can show:
@@ -490,17 +466,15 @@ instead of the plain and less informative:
 
  --output=s
 
-}
-
 =item * B<pass> => I<str>
 
 =item * B<str1>* => I<str>
 
-{en_US A required option as well as positional argument}.
+A required option as well as positional argument.
 
 =item * B<with_foo> => I<bool>
 
-{en_US This demonstrate negation of --with-foo to --without-foo}.
+This demonstrate negation of --with-foo to --without-foo.
 
 =back
 
@@ -518,7 +492,7 @@ Return value:  (any)
 
 =head2 demo_cli_opts_shorter(%args) -> [status, msg, result, meta]
 
-{en_US Function summary}.
+Function summary.
 
 Examples:
 
@@ -534,13 +508,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<bool1> => I<bool>
 
-{en_US Another bool option}.
+Another bool option.
 
 =item * B<flag1> => I<bool>
 
 =item * B<str1>* => I<str>
 
-{en_US A required option as well as positional argument}.
+A required option as well as positional argument.
 
 =back
 
