@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineResMeta;
 
-our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010;
 use strict;
@@ -88,14 +88,14 @@ Perinci::Examples::CmdLineResMeta - Functions in this package contains cmdline.*
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Examples::CmdLineResMeta (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.50 of Perinci::Examples::CmdLineResMeta (from Perl distribution Perinci-Examples), released on 2015-03-18.
 
 =head1 FUNCTIONS
 
 
 =head2 default_format() -> [status, msg, result, meta]
 
-{en_US Set cmdline.default_format json}.
+Set cmdline.default_format json.
 
 No arguments.
 
@@ -113,7 +113,7 @@ Return value:  (any)
 
 =head2 exit_code() -> [status, msg, result, meta]
 
-{en_US Returns cmdline exit code 7, even though status is 200}.
+Returns cmdline exit code 7, even though status is 200.
 
 No arguments.
 
@@ -131,7 +131,7 @@ Return value:  (any)
 
 =head2 is_palindrome(%args) -> [status, msg, result, meta]
 
-{en_US Return true if string is palindrome}.
+Return true if string is palindrome.
 
 Arguments ('*' denotes required arguments):
 
@@ -155,7 +155,7 @@ Return value:  (any)
 
 =head2 result() -> [status, msg, result, meta]
 
-{en_US Returns false, but cmdline.result the string "false"}.
+Returns false, but cmdline.result the string "false".
 
 No arguments.
 
@@ -173,7 +173,7 @@ Return value:  (any)
 
 =head2 skip_format() -> [status, msg, result, meta]
 
-{en_US Set cmdline.skip_format => 1}.
+Set cmdline.skip_format => 1.
 
 No arguments.
 
