@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010;
 use strict;
@@ -77,6 +77,30 @@ sub cmdline_src_file {
      {'func.args'=>\%args}];
 }
 
+$SPEC{cmdline_src_stdin_or_file_str} = {
+    v => 1.1,
+    summary => 'This function has str arg with cmdline_src=stdin_or_file',
+    args => {
+        a1 => {schema=>'str*', cmdline_src=>'stdin_or_file'},
+    },
+};
+sub cmdline_src_stdin_or_file_str {
+    my %args = @_;
+    [200, "OK", "a1=$args{a1}", {'func.args'=>\%args}];
+}
+
+$SPEC{cmdline_src_stdin_or_file_array} = {
+    v => 1.1,
+    summary => 'This function has array arg with cmdline_src=stdin_or_file',
+    args => {
+        a1 => {schema=>'array*', cmdline_src=>'stdin_or_file'},
+    },
+};
+sub cmdline_src_stdin_or_file_array {
+    my %args = @_;
+    [200, "OK", "a1=[".join(",",@{ $args{a1} })."]", {'func.args'=>\%args}];
+}
+
 $SPEC{cmdline_src_stdin_or_files_str} = {
     v => 1.1,
     summary => 'This function has str arg with cmdline_src=stdin_or_files',
@@ -189,14 +213,14 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.50 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-03-18.
 
 =head1 FUNCTIONS
 
 
 =head2 cmdline_src_file(%args) -> [status, msg, result, meta]
 
-{en_US This function has args with cmdline_src _file}.
+This function has args with cmdline_src _file.
 
 Arguments ('*' denotes required arguments):
 
@@ -222,7 +246,7 @@ Return value:  (any)
 
 =head2 cmdline_src_invalid_arg_type(%args) -> [status, msg, result, meta]
 
-{en_US This function has non-str/non-array arg with cmdline_src}.
+This function has non-str/non-array arg with cmdline_src.
 
 Arguments ('*' denotes required arguments):
 
@@ -246,7 +270,7 @@ Return value:  (any)
 
 =head2 cmdline_src_multi_stdin(%args) -> [status, msg, result, meta]
 
-{en_US This function has multiple args with cmdline_src stdin/stdin_or_files}.
+This function has multiple args with cmdline_src stdin/stdin_or_files.
 
 Arguments ('*' denotes required arguments):
 
@@ -272,11 +296,9 @@ Return value:  (any)
 
 =head2 cmdline_src_multi_stdin_line(%args) -> [status, msg, result, meta]
 
-{en_US This function has several stdin_line arguments}.
+This function has several stdin_line arguments.
 
-{en_US 
 And one also has its is_password property set to true.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -304,7 +326,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_array(%args) -> [status, msg, result, meta]
 
-{en_US This function has arg with cmdline_src=stdin}.
+This function has arg with cmdline_src=stdin.
 
 Arguments ('*' denotes required arguments):
 
@@ -328,7 +350,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_line(%args) -> [status, msg, result, meta]
 
-{en_US This function has a single stdin_line argument}.
+This function has a single stdin_line argument.
 
 Arguments ('*' denotes required arguments):
 
@@ -352,9 +374,57 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 cmdline_src_stdin_or_file_array(%args) -> [status, msg, result, meta]
+
+This function has array arg with cmdline_src=stdin_or_file.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<a1> => I<array>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 cmdline_src_stdin_or_file_str(%args) -> [status, msg, result, meta]
+
+This function has str arg with cmdline_src=stdin_or_file.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<a1> => I<str>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 cmdline_src_stdin_or_files_array(%args) -> [status, msg, result, meta]
 
-{en_US This function has array arg with cmdline_src=stdin_or_files}.
+This function has array arg with cmdline_src=stdin_or_files.
 
 Arguments ('*' denotes required arguments):
 
@@ -378,7 +448,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_files_str(%args) -> [status, msg, result, meta]
 
-{en_US This function has str arg with cmdline_src=stdin_or_files}.
+This function has str arg with cmdline_src=stdin_or_files.
 
 Arguments ('*' denotes required arguments):
 
@@ -402,7 +472,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_str(%args) -> [status, msg, result, meta]
 
-{en_US This function has arg with cmdline_src=stdin}.
+This function has arg with cmdline_src=stdin.
 
 Arguments ('*' denotes required arguments):
 
@@ -426,7 +496,7 @@ Return value:  (any)
 
 =head2 cmdline_src_unknown(%args) -> [status, msg, result, meta]
 
-{en_US This function has arg with unknown cmdline_src value}.
+This function has arg with unknown cmdline_src value.
 
 Arguments ('*' denotes required arguments):
 
@@ -450,12 +520,10 @@ Return value:  (any)
 
 =head2 test_binary(%args) -> [status, msg, result, meta]
 
-{en_US Accept binary in stdin/file}.
+Accept binary in stdin/file.
 
-{en_US 
 This function is like the one in C<Perinci::Examples> but argument is accepted
 via C<stdin_or_files>.
-}
 
 Arguments ('*' denotes required arguments):
 
