@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
-our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010;
 use strict;
@@ -170,21 +170,19 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.50 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-03-18.
 
 =head1 DESCRIPTION
 
 
-{en_US 
 This package contains functions that demonstrate streaming input/output.
-}
 
 =head1 FUNCTIONS
 
 
 =head2 hash_stream(%args) -> [status, msg, result, meta]
 
-{en_US This function produces a stream of hashes}.
+This function produces a stream of hashes.
 
 Arguments ('*' denotes required arguments):
 
@@ -208,7 +206,7 @@ Return value:  (hash)
 
 =head2 nat(%args) -> [status, msg, result, meta]
 
-{en_US This function produces a stream of natural numbers}.
+This function produces a stream of natural numbers.
 
 Arguments ('*' denotes required arguments):
 
@@ -232,7 +230,7 @@ Return value:  (int)
 
 =head2 square_input(%args) -> [status, msg, result, meta]
 
-{en_US This function squares its stream input}.
+This function squares its stream input.
 
 Arguments ('*' denotes required arguments):
 
@@ -256,7 +254,7 @@ Return value:  (float)
 
 =head2 wc(%args) -> [status, msg, result, meta]
 
-{en_US Count the number of lines/words/characters of input, like the "wc" command}.
+Count the number of lines/words/characters of input, like the "wc" command.
 
 Arguments ('*' denotes required arguments):
 
@@ -280,12 +278,10 @@ Return value:  (str)
 
 =head2 wc_keys(%args) -> [status, msg, result, meta]
 
-{en_US Count the number of keys of each hash}.
+Count the number of keys of each hash.
 
-{en_US 
 This is a simple demonstration of accepting a stream of hashes. In command-line
 application this will translate to JSON stream.
-}
 
 Arguments ('*' denotes required arguments):
 
