@@ -1,7 +1,7 @@
 package Perinci::Examples::SubMeta;
 
-our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010;
 use strict;
@@ -167,12 +167,11 @@ Perinci::Examples::SubMeta - Test argument submetadata
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Examples::SubMeta (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.50 of Perinci::Examples::SubMeta (from Perl distribution Perinci-Examples), released on 2015-03-18.
 
 =head1 DESCRIPTION
 
 
-{en_US 
 Argument submetadata is introduced in Rinci 1.1.55, mainly to support (complex)
 form. With this, you can submit a complex form (one that has subforms) to a
 function. The function will receive the form submission as a nested data
@@ -181,16 +180,14 @@ structure.
 To add an argument submetadata, you specify a hash argument with a C<meta>
 property, or an array argument with C<element_meta> property. The value of the
 property is another Rinci function metadata.
-}
 
 =head1 FUNCTIONS
 
 
 =head2 register_donors(%args) -> [status, msg, result, meta]
 
-{en_US Register donor(s)}.
+Register donor(s).
 
-{en_US 
 This example function registers one or more blood donors. For each donor, you
 need to specify at least the name, gender, age, and blood type.
 
@@ -204,7 +201,6 @@ In the command-line, you can specify them as follow:
 
 Actually, this function just returns its arguments. This function demonstrates
 argument element submetadata.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -212,7 +208,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<date>* => I<date>
 
-{en_US Planned donation date}.
+Planned donation date.
 
 =item * B<donor>* => I<array>
 
@@ -232,15 +228,13 @@ Return value:  (any)
 
 =head2 register_student(%args) -> [status, msg, result, meta]
 
-{en_US Register a student to a class}.
+Register a student to a class.
 
-{en_US 
 This example function registers a student to a class. You specify the student's
 name, gender, and age, as well as the desired class to register to. You can only
 register one student at a time.
 
 Actually, this function just returns its arguments.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -248,7 +242,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<class> => I<str>
 
-{en_US Desired class}.
+Desired class.
 
 =item * B<note>* => I<str>
 
