@@ -1,7 +1,7 @@
 package Perinci::Examples::Tx;
 
-our $DATE = '2015-01-20'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010;
 use strict;
@@ -39,14 +39,14 @@ Perinci::Examples::Tx - Examples for using transaction
 
 =head1 VERSION
 
-This document describes version 0.49 of Perinci::Examples::Tx (from Perl distribution Perinci-Examples), released on 2015-01-20.
+This document describes version 0.50 of Perinci::Examples::Tx (from Perl distribution Perinci-Examples), released on 2015-03-18.
 
 =head1 FUNCTIONS
 
 
 =head2 check_state() -> [status, msg, result, meta]
 
-{en_US Return 'check_state' if checking state, otherwise empty string}.
+Return 'check_state' if checking state, otherwise empty string.
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
